@@ -63,7 +63,6 @@ class HypeParser(optparse.OptionParser):
     ):
         
         self.commands = commands
-        self.commands.append(self._HelpCommand)
         self.options = options
 
         if 'usage' not in self.options:
@@ -98,6 +97,29 @@ class HypeParser(optparse.OptionParser):
 
         self.commands.append(cmd)
 
+    def remove_command(self, name: str):
+        """
+        Remove the command name to the list of registered command. 
+        
+        Parameters
+        ---
+            name (str):
+                The name of the command to be removed.
+
+        Example:
+
+            >>> goodbye = HypeCommand(..)
+            >>> parser = HyperParser(...)
+            >>> ...
+            >>> parser.add_command(goodbye)
+            >>> parser.remove_command('goodbye')
+
+        """
+
+        for command in self.commands:
+            if command.name == name:
+                self.commands.remove(command)
+
 
     def format_help(self, formatter=None) -> str:
         out = optparse.OptionParser.format_help(self, formatter)
@@ -209,7 +231,8 @@ class HypeParser(optparse.OptionParser):
             >>> options, command, \ 
             ...    command_opt, command_args = parser.parse_args()
     
-        """ 
+        """
+        self.commands.insert(len(self.commands), self._HelpCommand)
         options, args = optparse.OptionParser.parse_args(self, _args, _value)
 
         if not args:
